@@ -3,11 +3,10 @@
 # It has some helper properties to access date ranges and hierarchical details
 # ------------------------------------------------------------------------------ #
 
-import datetime
 import logging
-
 import numpy as np
-from pymc3 import Model  # this import is needed to get pymc3-style "with ... as model:"
+from datetime import datetime, timedelta
+from pymc import Model  # this import is needed to get pymc-style "with ... as model:"
 
 # we cannot import utility, would create recursive dependencies
 # from . import utility as ut
@@ -18,89 +17,89 @@ log = logging.getLogger(__name__)
 # can we rename this guy to model base or something?
 class Cov19Model(Model):
     """
-        Abstract base class for the dynamic model of covid-19 propagation.
-        Derived from :class:`pymc3.Model`.
+    Abstract base class for the dynamic model of COVID-19 propagation.
+    Derived from :class:`pymc.Model`.
 
-        Parameters below are passed to the constructor.
+    Parameters below are passed to the constructor.
 
-        Attributes (Variables) are available after creation and can be accessed from
-        every instance. Some background:
+    Attributes (Variables) are available after creation and can be accessed from
+    every instance. Some background:
 
-            * The simulation starts `diff_data_sim` days before the data.
-            * The data has a certain length, on which the inference is based. This
-              length is given by `new_cases_obs`.
-            * After the inference, a forecast takes of length `fcast_len` takes
-              place, starting on the day after the last data point in `new_cases_obs`.
-            * In total, traces produced by a model run have the length
-              `sim_len = diff_data_sim + data_len + fcast_len`
-            * Date ranges include both boundaries. For example, if `data_begin` is March
-              1 and `data_end` is March 3 then `data_len` will be 3.
+        * The simulation starts `diff_data_sim` days before the data.
+        * The data has a certain length, on which the inference is based. This
+          length is given by `new_cases_obs`.
+        * After the inference, a forecast takes of length `fcast_len` takes
+          place, starting on the day after the last data point in `new_cases_obs`.
+        * In total, traces produced by a model run have the length
+          `sim_len = diff_data_sim + data_len + fcast_len`
+        * Date ranges include both boundaries. For example, if `data_begin` is March
+          1 and `data_end` is March 3 then `data_len` will be 3.
 
-        Parameters
-        ----------
-        new_cases_obs : 1 or 2d array
-            If the array is two-dimensional, an hierarchical model will be constructed.
-            First dimension is then time, the second the region/country.
-        data_begin : datatime.datetime
-            Date of the first data point
-        fcast_len : int
-            Number of days the simulations runs longer than the data
-        diff_data_sim : int
-            Number of days the simulation starts earlier than the data. Should be
-            significantly longer than the delay between infection and report of cases.
-        N_population : number or 1d array
-            Number of inhabitance in region, needed for the S(E)IR model. Is ideally 1
-            dimensional if new_cases_obs is 2 dimensional
-        name : string
-            suffix appended to the name of random variables saved in the trace
-        model :
-            specify a model, if this one should expand another
-        shifted_cases : bool
-            when enabled (True), interprets short intervals of zero cases as days,
-            where no reporting happens and adds model cases to next non-zero-case day
+    Parameters
+    ----------
+    new_cases_obs : 1 or 2d array
+        If the array is two-dimensional, an hierarchical model will be constructed.
+        First dimension is then time, the second the region/country.
+    data_begin : :class:`~datetime.datetime`
+        Date of the first data point
+    fcast_len : int
+        Number of days the simulations runs longer than the data
+    diff_data_sim : int
+        Number of days the simulation starts earlier than the data. Should be
+        significantly longer than the delay between infection and report of cases.
+    N_population : number or 1d array
+        Number of inhabitance in region, needed for the S(E)IR model. Is ideally 1
+        dimensional if new_cases_obs is 2 dimensional
+    name : string
+        suffix appended to the name of random variables saved in the trace
+    model :
+        specify a model, if this one should expand another
+    shifted_cases : bool
+        when enabled (True), interprets short intervals of zero cases as days,
+        where no reporting happens and adds model cases to next non-zero-case day
 
-        Attributes
-        ----------
-        new_cases_obs : 1 or 2d array
-            as passed during construction
+    Attributes
+    ----------
+    new_cases_obs : 1 or 2d array
+        as passed during construction
 
-        data_begin : datatime.datetime
-            date of the first data point in the data
+    data_begin : :class:`~datetime.datetime`
+        date of the first data point in the data
 
-        data_end : datatime.datetime
-            date of the last data point in the data
+    data_end : :class:`~datetime.datetime`
+        date of the last data point in the data
 
-        sim_begin : datatime.datetime
-            date at which the simulation begins
+    sim_begin : :class:`~datetime.datetime`
+        date at which the simulation begins
 
-        sim_end : datatime.datetime
-            date at which the simulation ends (should match fcast_end)
+    sim_end : :class:`~datetime.datetime`
+        date at which the simulation ends (should match fcast_end)
 
-        fcast_begin : datatime.datetime
-            date at which the forecast starts (should be one day after data_end)
+    fcast_begin : :class:`~datetime.datetime`
+        date at which the forecast starts (should be one day after data_end)
 
-        fcast_end : datatime.datetime
-            data at which the forecast ends
+    fcast_end : :class:`~datetime.datetime`
+        data at which the forecast ends
 
-        data_len : int
-            total number of days in the data
+    data_len : int
+        total number of days in the data
 
-        sim_len : int
-            total number of days in the simulation
+    sim_len : int
+        total number of days in the simulation
 
-        fcast_len : int
-            total number of days in the forecast
+    fcast_len : int
+        total number of days in the forecast
 
-        diff_data_sim : int
-            difference in days between the simulation begin and the data begin.
-            The simulation starting time is usually earlier than the data begin.
+    diff_data_sim : int
+        difference in days between the simulation begin and the data begin.
+        The simulation starting time is usually earlier than the data begin.
 
-        Example
-        -------
-        .. code-block::
+    Example
+    -------
+    .. code-block::
 
-            with Cov19Model(**params) as model:
-                # Define model here
+        with Cov19Model(**params) as model:
+            # Define model here
     """
 
     def __init__(
@@ -111,12 +110,12 @@ class Cov19Model(Model):
         diff_data_sim,
         N_population,
         data_end=None,
-        name="",
         model=None,
+        name="",
         shifted_cases=True,
     ):
 
-        super().__init__(name=name, model=model)
+        super().__init__(name, model)
 
         new_cases_obs[
             new_cases_obs < 0
@@ -139,11 +138,9 @@ class Cov19Model(Model):
 
         # assign properties
         self._data_begin = data_begin
-        self._sim_begin = self.data_begin - datetime.timedelta(days=diff_data_sim)
+        self._sim_begin = self.data_begin - timedelta(days=diff_data_sim)
         if data_end is None:
-            self._data_end = self.data_begin + datetime.timedelta(
-                days=len(new_cases_obs) - 1
-            )
+            self._data_end = self.data_begin + timedelta(days=len(new_cases_obs) - 1)
             # totel length of simulation, get later via the shape
             sim_len = len(new_cases_obs) + diff_data_sim + fcast_len
             if sim_len < len(new_cases_obs) + diff_data_sim:
@@ -156,7 +153,7 @@ class Cov19Model(Model):
                 (self.data_end - self.data_begin).days + 1 + diff_data_sim + fcast_len
             )
 
-        self._sim_end = self.data_end + datetime.timedelta(days=fcast_len)
+        self._sim_end = self.data_end + timedelta(days=fcast_len)
 
         # shape and dimension of simulation
         if self.sim_ndim == 1:
@@ -170,7 +167,7 @@ class Cov19Model(Model):
                 self.new_cases_obs.shape[2],
             )
 
-        if self.data_end > datetime.datetime.today():
+        if self.data_end > datetime.today():
             log.warning(
                 f"Your last data point is in the future ({self.data_end}). "
                 + "Are you traveling faster than light?"
@@ -202,7 +199,7 @@ class Cov19Model(Model):
     @property
     def fcast_begin(self):
         # Returns date on which the forecast starts i.e. the day after the data ends
-        return self.data_end + datetime.timedelta(days=1)
+        return self.data_end + timedelta(days=1)
 
     @property
     def fcast_end(self):
@@ -261,16 +258,16 @@ class Cov19Model(Model):
     @property
     def untransformed_freeRVs(self):
         """
-            Returns the names of all free parameters of the model, usefull for plotting!
+        Returns the names of all free parameters of the model, usefull for plotting!
 
-            Returns
-            -------
-            : list
-                all variable names
+        Returns
+        -------
+        : list
+            all variable names
         """
 
         """
-            For every free random varibale in pymc3 with the _log__ suffix there exists
+            For every free random varibale in pymc with the _log__ suffix there exists
             an Random Variable without logscale i.e. without _log__. There is no
             easy function to return the names of these function that's why we
             Get the names like that.
@@ -281,24 +278,9 @@ class Cov19Model(Model):
 
 def modelcontext(model):
     """
-        return the given model or try to find it in the context if there was
-        none supplied.
+    return the given model or try to find it in the context if there was
+    none supplied.
     """
     if model is None:
         return Cov19Model.get_context()
     return model
-
-
-def set_missing_priors_with_default(priors_dict, default_priors):
-    """
-        Takes a dict with custom priors and a dict with defaults and sets keys that
-        are not given
-    """
-    for prior_name in priors_dict.keys():
-        if prior_name not in default_priors:
-            log.warning(f"Prior with name {prior_name} not known")
-
-    for prior_name, value in default_priors.items():
-        if prior_name not in priors_dict:
-            priors_dict[prior_name] = value
-            log.info(f"{prior_name} was set to default value {value}")
