@@ -2,7 +2,7 @@
     # Non-hierarchical model using jhu data (no regions).
     Reproduces Dehning et al. arXiv:2004.01105 Figure 3
 
-    Runtime ~ 5 min
+    Runtime ~ 15 min
 
     In the new code we have implemented smoother transitions at the change points
     via sigmoids instead of the linear transient.
@@ -12,7 +12,7 @@
 """
 import datetime
 import sys
-import pymc3 as pm
+import pymc as pm
 import numpy as np
 import matplotlib as mpl
 import matplotlib.pyplot as plt
@@ -91,12 +91,12 @@ with cov19.Cov19Model(**params_model) as this_model:
     )
 
     # Adds the recovery rate mu to the model as a random variable
-    mu = pm.Lognormal(name="mu", mu=np.log(1 / 8), sigma=0.2)
+    mu = pm.LogNormal(name="mu", mu=np.log(1 / 8), sigma=0.2)
 
     # This builds a decorrelated prior for I_begin for faster inference. It is not
     # necessary to use it, one can simply remove it and use the default argument for
     # pr_I_begin in cov19.model.SIR
-    prior_I = cov19.model.uncorrelated_prior_I(
+    I_begin = cov19.model.uncorrelated_prior_I(
         lambda_t_log=lambda_t_log,
         mu=mu,
         pr_median_delay=pr_delay,
@@ -106,17 +106,18 @@ with cov19.Cov19Model(**params_model) as this_model:
 
     # Use lambda_t_log and mu as parameters for the SIR model.
     # The SIR model generates the inferred new daily cases.
-    new_cases = cov19.model.SIR(lambda_t_log=lambda_t_log, mu=mu, pr_I_begin=prior_I)
+    new_cases = cov19.model.SIR(lambda_t_log=lambda_t_log, mu=mu, I_begin=I_begin)
 
-    # Delay the cases by a lognormal reporting delay and add them as a trace variable
+    # Delay the cases by a lognormal reporting delay
     new_cases = cov19.model.delay_cases(
         cases=new_cases,
-        name_cases="delayed_cases",
-        pr_mean_of_median=pr_delay,
-        pr_sigma_of_median=0.2,
-        pr_median_of_width=0.3,
+        median_delay_kwargs={
+            "name": "delay",
+            "mu":pr_delay,
+            "sigma":0.2
+        }
     )
-
+    
     # Modulate the inferred cases by a abs(sin(x)) function, to account for weekend effects
     # Also adds the "new_cases" variable to the trace that has all model features.
     new_cases = cov19.model.week_modulation(cases=new_cases, name_cases="new_cases")
@@ -128,43 +129,59 @@ with cov19.Cov19Model(**params_model) as this_model:
 """## engage!
     Reduce tune and/or draws to speed things up.
 """
-trace = pm.sample(model=this_model, tune=500, draws=1000, init="advi+adapt_diag")
+idata = pm.sample(model=this_model, tune=500, draws=1000, init="advi+adapt_diag")
 
 
 """## plotting
 """
-fig, axes = cov19.plot.timeseries_overview(this_model, trace, offset=cum_cases[0])
+fig, axes = cov19.plot.timeseries_overview(this_model, idata, offset=cum_cases[0])
 
 fig, axes = plt.subplots(6, 3, figsize=(4, 6.4))
 axes[0, 2].set_visible(False)
 axes[1, 2].set_visible(False)
 
 # left column
-for i, key in enumerate(
-    ["weekend_factor", "mu", "lambda_0", "lambda_1", "lambda_2", "lambda_3"]
+for i, (key, math) in enumerate(
+    zip(["weekend_factor", "mu", "lambda_0", "lambda_1", "lambda_2", "lambda_3"],
+    ["\Phi_w","\mu","\lambda_0", "\lambda_1", "\lambda_2", "\lambda_3"])
 ):
-    cov19.plot._distribution(this_model, trace, key, ax=axes[i, 0])
+    cov19.plot.distribution(this_model, idata, key, ax=axes[i, 0], dist_math=math)
 
 # mid column
-for i, key in enumerate(
-    [
+for i, (key, math) in enumerate(
+    zip([
         "offset_modulation",
         "sigma_obs",
         "I_begin",
-        # beware, these guys were the begin of the transient in the paper,
-        # now they are the center points (shifted by transient_len_i)
         "transient_day_1",
         "transient_day_2",
         "transient_day_3",
-    ]
+    ],    [
+        "f_w",
+        "\sigma_{obs}",
+        "I_0",
+        "t_1",
+        "t_2",
+        "t_3",
+    ])
 ):
-    cov19.plot._distribution(this_model, trace, key, ax=axes[i, 1])
+    cov19.plot.distribution(this_model, idata, key, ax=axes[i, 1],dist_math=math,)
 
 # right column
-for i, key in enumerate(
-    ["delay", "transient_len_1", "transient_len_2", "transient_len_3",]
+for i, (key,math) in enumerate(
+    zip([
+        "delay",
+        "transient_len_1",
+        "transient_len_2",
+        "transient_len_3",
+    ],[
+        "D",
+        "\Delta t_1",
+        "\Delta t_2",
+        "\Delta t_3"
+    ])
 ):
-    cov19.plot._distribution(this_model, trace, key, ax=axes[i + 2, 2])
+    cov19.plot.distribution(this_model, idata, key, ax=axes[i + 2, 2],dist_math=math,)
 
 fig.tight_layout()
-fig  # To show figure in jupyter notebook
+fig  # To show figure in jupyter notebook
\ No newline at end of file
